# Optimizers

This directory contains a small collection of optimizer shims that can be used in [`mlos_bench`](../../../mlos_bench/) to help optimize the [`Tunables`](../tunables/) in an [`Environment`](../environments/).

In general, we expect that the optimizer will be one provided by the [`mlos_core`](../../../mlos_core/) optimizer abstraction.
